#
# spec file for package drkonqi6
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.5.0
%define qt6_version 6.7.0

%define rname drkonqi

%bcond_without released
Name:           drkonqi6
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
Version:        6.2.5
Release:        1.1
Summary:        Helper for debugging and reporting crashes
License:        GPL-2.0-or-later
URL:            https://www.kde.org/
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IdleTime) >= %{kf6_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6SyntaxHighlighting) >= %{kf6_version}
BuildRequires:  cmake(KF6UserFeedback) >= %{kf6_version}
BuildRequires:  cmake(KF6Wallet) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(PolkitQt6-1)
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(libsystemd)
# To install debug packages
Requires:       konsole
# QML runtime dependencies (not detected automatically because the QML code is embedded as Qt Resource)
# if kirigami2 is not installed, it falls back to the old QWidgets-based UI though and doesn't need them...
Requires:       (kf6-kdeclarative-imports if kf6-kirigami-imports)
Requires:       python3-psutil
Requires:       (kf6-kitemmodels-imports if kf6-kirigami-imports)
Requires:       (kf6-syntax-highlighting-imports if kf6-kirigami-imports)
# The gdb script for crash info extraction can use this for reporting error
# of the error extraction itself. The openSUSE package has all integrations
# listed as hard requirements though, which pulls in 260MiB of pure bloat.
# Recommends:   python3-sentry-sdk
# Only needed for QML traces
Recommends:     python3-pygdbmi
# We want useful backtraces
Recommends:     gdb
# we want symbol install support
Recommends:     ptools
Provides:       drkonqi5 = %{version}
Obsoletes:      drkonqi5 < %{version}
Obsoletes:      drkonqi5-lang < %{version}
# In theory the coredump integration could be split into a subpackage
# and supplement systemd-coredump, but it's small enough to not be worth it.
# This however means there can't be any dependency on systemd-coredump, to
# not pull it in unconditionally.
%{?systemd_ordering}

%description
The KDE Crash Handler gives the user feedback if a program has crashed.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 \
  -DWITH_PYTHON_VENDORING:BOOL=FALSE
# Temporarily disabled to test if generating backtraces gets better without it
# %%if 0%%{?suse_version} >= 1550
#   -DWITH_GDB12:BOOL=TRUE
# %%endif

%kf6_build

%install
%kf6_install

%find_lang drkonqi

install -p -D -m755 src/doc/examples/installdbgsymbols_suse.sh \
%{buildroot}%{_kf6_bindir}/installdbgsymbols.sh

%pre
%service_add_pre drkonqi-coredump-processor@.service

%post
%{systemd_user_post drkonqi-coredump-cleanup.service drkonqi-coredump-cleanup.timer drkonqi-coredump-launcher.socket drkonqi-sentry-postman.path drkonqi-sentry-postman.service drkonqi-sentry-postman.timer}
%service_add_post drkonqi-coredump-processor@.service

%preun
%{systemd_user_preun drkonqi-coredump-cleanup.service drkonqi-coredump-cleanup.timer drkonqi-coredump-launcher.socket drkonqi-coredump-pickup.service drkonqi-sentry-postman.path drkonqi-sentry-postman.service drkonqi-sentry-postman.timer}
%service_del_preun drkonqi-coredump-processor@.service

%postun
%{systemd_user_postun drkonqi-coredump-cleanup.service drkonqi-coredump-cleanup.timer drkonqi-coredump-launcher.socket drkonqi-coredump-pickup.service drkonqi-sentry-postman.path drkonqi-sentry-postman.service drkonqi-sentry-postman.timer}
%service_del_postun_without_restart drkonqi-coredump-processor@.service

%files
%license LICENSES/*
%{_kf6_applicationsdir}/org.kde.drkonqi.coredump.gui.desktop
%{_kf6_applicationsdir}/org.kde.drkonqi.desktop
%{_kf6_bindir}/drkonqi-coredump-gui
# Not optional anymore but opt-in
%{_kf6_bindir}/drkonqi-sentry-data
%{_kf6_bindir}/installdbgsymbols.sh
%{_kf6_debugdir}/drkonqi.categories
%{_kf6_libexecdir}/drkonqi-polkit-helper
%dir %{_kf6_plugindir}/drkonqi/
%{_kf6_plugindir}/drkonqi/KDECoredumpNotifierTruck.so
%{_kf6_sharedir}/dbus-1/system-services/org.kde.drkonqi.service
%{_kf6_sharedir}/dbus-1/system.d/org.kde.drkonqi.conf
%{_kf6_sharedir}/polkit-1/actions/org.kde.drkonqi.policy
%{_kf6_sharedir}/drkonqi/
%{_libexecdir}/drkonqi
%{_libexecdir}/drkonqi-coredump-cleanup
%{_libexecdir}/drkonqi-coredump-launcher
%{_libexecdir}/drkonqi-coredump-processor
%{_libexecdir}/drkonqi-sentry-postman
%{_unitdir}/drkonqi-coredump-processor@.service
%dir %{_unitdir}/systemd-coredump@.service.wants
%{_unitdir}/systemd-coredump@.service.wants/drkonqi-coredump-processor@.service
%{_userunitdir}/drkonqi-coredump-cleanup.service
%{_userunitdir}/drkonqi-coredump-cleanup.timer
%{_userunitdir}/drkonqi-coredump-launcher.socket
%{_userunitdir}/drkonqi-coredump-launcher@.service
%{_userunitdir}/drkonqi-coredump-pickup.service
%{_userunitdir}/drkonqi-sentry-postman.path
%{_userunitdir}/drkonqi-sentry-postman.service
%{_userunitdir}/drkonqi-sentry-postman.timer
%dir %{_userunitdir}/default.target.wants
%{_userunitdir}/default.target.wants/drkonqi-coredump-cleanup.service
%{_userunitdir}/default.target.wants/drkonqi-sentry-postman.path
%dir %{_userunitdir}/plasma-core.target.wants
%{_userunitdir}/plasma-core.target.wants/drkonqi-coredump-pickup.service
%{_userunitdir}/plasma-core.target.wants/drkonqi-sentry-postman.path
%{_userunitdir}/plasma-core.target.wants/drkonqi-sentry-postman.timer
%dir %{_userunitdir}/sockets.target.wants
%{_userunitdir}/sockets.target.wants/drkonqi-coredump-launcher.socket
%dir %{_userunitdir}/timers.target.wants
%{_userunitdir}/timers.target.wants/drkonqi-coredump-cleanup.timer
%{_userunitdir}/timers.target.wants/drkonqi-sentry-postman.timer

%files lang -f drkonqi.lang

%changelog
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
  * connectiontest: log bad requests
  * connectiontest: fix for qt 6.8
  * auto starting jobs don't start early
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * kwallet: set folder explicitly
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
  * sentry: mark incompatible Qt's as such
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Changes since 6.1.5:
  * update version for new release
  * backtracegenerator: cache raw debugger output and give the user access to it (kde#477586,kde#474116,kde#478110)
  * preamble: more aggressively capture exceptions
  * Update file mappings
  * replace debugger definition files with in-code defintions
  * debugger: refactor backing data management
  * don't submit to sentry if the crashed app isn't targeting kde bugzilla
  * backtracegenerator: remove unused code
  * preamble: set a distribution identifier
  * Remove virtual keyword when we use override
  * qml: show context text for the report button (kde#491225)
  * Enhance messages to add notes about time taken
  * Use frameworks version number from kcrash
  * drop ptracer support
  * Improve default window proportions and layout
  * sentry: also send qt_version in the tags
  * support consuming the qt version from kcrash
  * coredump: synthesize crash metadata for kwin_x11
  * implement ANR support
  * Add finish button to automatic crash handler (kde#487767)
  * sentry: correctly use dbus interface name (kde#488555)
  * polkit: correctly call fcntl (kde#487727)
  * polkit: don't ignore fcntl errors
  * update version for new release
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * don't submit to sentry if the crashed app isn't targeting kde bugzilla
  * preamble: set a distribution identifier
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
  * Use frameworks version number from kcrash
  * sentry: also send qt_version in the tags
  * support consuming the qt version from kcrash
  * coredump: synthesize crash metadata for kwin_x11
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
  * sentry: correctly use dbus interface name (kde#488555)
* Sat Jun 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Do not pull in python3-sentry-sdk until its packaging is fixed
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
  * polkit: correctly call fcntl (kde#487727)
  * polkit: don't ignore fcntl errors
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Changes since 6.0.5:
  * update version for new release
  * postman: don't run too often
  * postman: disambiguate path unit
  * backtracegenerator: refactor process resetting
  * backtracegenerator: don't crash when the debugger crashes (kde#485669)
  * coredump/polkit: route core directly into the file descriptor
  * coredump/polkit: turn assert into early return
  * coredump/polkit: save the core into a file rather than a directory
  * coredump/polkit: refine the action message
  * coredump/polkit: rename the excavator action
  * coredump/polkit: implement copy_file_range fallback for renameat
  * coredump/polkit: assert directory is 0700
  * coredump/polkit: return early when excavation failed
  * coredump/polkit: put tmpDir on the stack
  * coredump/polkit: don't allow anything that looks like paths as input
  * dumpexcavator: fix dbus timeout handling
  * be more strict in rejecting useless traces
  * coredump-processor: replace sleep hack with in-process sleep (kde#484864)
  * backtracegenerator: add a setting to automatically fetch symbols from debuginfod
  * sentry: add more tags
  * gdb: limit amount of frames in backtrace to 128
  * Port to Kirigami version of ContextualHelpButton
  * reportinterface: default log entries to priority 'info'
  * Set systemd start timeout for drkonqi-coredump-pickup.service
  * Avoid unneeded QtQml module include
  * sentrypostbox: change user feedback name to DrKonqi
  * backtraceparser: uniquify missing libs list (kde#478929)
  * dumpexcavator: include unistd for close declaration (kde#479652)
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
  * postman: don't run too often
  * backtracegenerator: refactor process resetting
  * backtracegenerator: don't crash when the debugger crashes (kde#485669)
  * coredump/polkit: return early when excavation failed
  * coredump/polkit: put tmpDir on the stack
  * coredump/polkit: don't allow anything that looks like paths as input
  * dumpexcavator: fix dbus timeout handling
  * be more strict in rejecting useless traces
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * coredump-processor: replace sleep hack with in-process sleep (kde#484864)
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
  * sentry: add more tags
  * gdb: limit amount of frames in backtrace to 128
  * reportinterface: default log entries to priority 'info'
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * Set systemd start timeout for drkonqi-coredump-pickup.service
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * dumpexcavator: include unistd for close declaration (kde#479652)
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sun Dec  3 2023 Luca Beltrame <lbeltrame@kde.org>
- Dropped patch, as pygdbmi is no longer hard-required upstream:
  * Don-t-hard-require-pygdbmi.patch
* Fri Dec  1 2023 Christophe Marin <christophe@krop.fr>
- Add patch to avoid requiring pygdbmi:
  * Don-t-hard-require-pygdbmi.patch
* Fri Jul 14 2023 Christophe Marin <christophe@krop.fr>
- Init drkonqi6
